select 
	quote_ident(:'entry_type') as entry_type,
	quote_ident(:'db_source') as database_name,
	quote_ident(f.name) as db_id,
	quote_ident(concat(f.name, '_', :'db_name')) as db_version,
	-- quote_ident(f.name) as name,
	-- DESCRIPTION
	quote_ident(
		concat(f.name, ' is a ',type.name,' from ', props.species, ' (',props.common_name,') located between positions ', 
				floc.fmin, ' and ', floc.fmax, ' on ', srcf.name , ' and which properties are: ',
			concat_ws(', ',
				case 
					when f.seqlen IS NULL then concat('length = ',floc.fmax-floc.fmin)
					else concat('length = ',f.seqlen)
				end,
				props.properties
			)
		)
	) as description,
	quote_ident(concat(:'url_base', f.name)) as url,
	quote_ident(props.species) as species, 
	'""' as xref,
	quote_ident(type.name) as feature_type,
	'""' as sequence_id,
	'""' as sequence_version,
	floc.fmin as start_position,
	floc.fmax as end_position,
	'""' as map,
	'""' as map_position,
	'""' as authority,
	'""' as trait,
	'""' as trait_id,
	'""' as environment,
	'""' as environment_id,
	'""' as statistic,
	'""' as unit,
	'""' as genotype,
	'""' as experiment_type
from 
	(
	select distinct props2.fid, string_agg(pair, ',') as properties, concat(genus,' ',species) as species,
			org.common_name as common_name, upper(concat('SEQ_FEAT_CHADO_', :'db_name', '_', genus, '_', species, '_', props2.fid))  as database_id from 
		(select distinct 
			f.feature_id as fid, fpterm.name as fpname, fp.value as fpval, f.organism_id as org_id,
			concat(fpterm.name, ' = ', fp.value) as pair 
		from feature f
			left outer join featureprop fp on f.feature_id = fp.feature_id
			join cvterm fpterm on fp.type_id = fpterm.cvterm_id
		where f.type_id != (select cvterm_id from cvterm where name = 'match_part')
		order by fpterm.name, fp.value asc -- always get pairs in alphabetical order, not?! Duh!
		) as props2
		join organism org on props2.org_id = org.organism_id
		group by props2.fid, genus, species, common_name, database_id 
	) as props -- aggregate features' properties into a single column
	join feature f on props.fid=f.feature_id
	join cvterm type on f.type_id = type.cvterm_id
	join featureloc floc on f.feature_id = floc.feature_id and floc.rank = 0
	left outer join feature srcf on floc.srcfeature_id=srcf.feature_id
;